# FFTW FAQ - Section 1
Introduction and General Information

- Q1.1. What is FFTW?
- Q1.2. How do I obtain FFTW?
- Q1.3. Is FFTW free software?
- Q1.4. What is this about non-free licenses?
- Q1.5. In the West? I thought MIT was in the East?

## Question 1.1. What is FFTW?

FFTW is a free collection of fast C routines for computing the Discrete Fourier Transform in one or more dimensions. It includes complex, real, symmetric, and parallel transforms, and can handle arbitrary array sizes efficiently. FFTW is typically faster than other publically-available FFT implementations, and is even competitive with vendor-tuned libraries. (See our web page for extensive benchmarks.) To achieve this performance, FFTW uses novel code-generation and runtime self-optimization techniques (along with many other tricks).

## Question 1.2. How do I obtain FFTW?

FFTW can be found at the FFTW web page. You can also retrieve it from `ftp.fftw.org` in `/pub/fftw`.

## Question 1.3. Is FFTW free software?

Starting with version 1.3, FFTW is Free Software in the technical sense defined by the Free Software Foundation (see Categories of Free and Non-Free Software), and is distributed under the terms of the GNU General Public License. Previous versions of FFTW were distributed without fee for noncommercial use, but were not technically ``free.''

Non-free licenses for FFTW are also available that permit different terms of use than the GPL.

## Question 1.4. What is this about non-free licenses?

The non-free licenses are for companies that wish to use FFTW in their products but are unwilling to release their software under the GPL (which would require them to release source code and allow free redistribution). Such users can purchase an unlimited-use license from MIT. Contact us for more details.

We could instead have released FFTW under the LGPL, or even disallowed non-Free usage. Suffice it to say, however, that MIT owns the copyright to FFTW and they only let us GPL it because we convinced them that it would neither affect their licensing revenue nor irritate existing licensees.

## Question 1.5. In the West? I thought MIT was in the East?

Not to an Italian. You could say that we're a Spaghetti Western (with apologies to Sergio Leone).

Next: Installing FFTW.
Return to contents.

Extracted from FFTW Frequently Asked Questions with Answers, Copyright © 2021 Matteo Frigo and Massachusetts Institute of Technology.